# @(#)src/agent/common/ag_i18n_inc.pm	2.1 07/02/03 14:24:30 - 
# ident "@(#)VCS:src/agent/common/ag_i18n_inc.pm 2.1"
#
# START COPYRIGHT-NOTICE: 2003
# 
# Copyright 2003 VERITAS Software Corporation.
# All rights reserved.
# 
# VERITAS, VERITAS SOFTWARE, the VERITAS logo and all other VERITAS
# product names and slogans are trademarks or registered trademarks
# of VERITAS Software Corporation in the USA and/or other countries.
# Other product names and/or slogans mentioned herein may be trade-
# marks or registered trademarks of their respective companies.
# 
# END COPYRIGHT-NOTICE.
#
# exported functions can be used after doing the following:
#       use ag_i18n_inc;

package ag_i18n_inc;
use Exporter;
@ISA = ('Exporter');
@EXPORT = ('VCSAG_SET_ENVS', 'VCSAG_LOG_MSG', 'VCSAG_LOGDBG_MSG');

use File::Basename;
use POSIX qw(uname);
use strict;

my ($ACTION_ENTRY_PT) = "actions";
my ($VCSHOME, $HALOG, $SYSTEM, $FILE_NAME, $AGENT_DIR, $VCSAG_OS);
my ($VCS_LOG_CATEGORY, $VCS_LOG_SCRIPT_NAME, $VCS_LOG_AGENT_NAME);

$VCSHOME = $ENV{"VCS_HOME"};
$VCSHOME = "/opt/VRTSvcs" unless (defined ($VCSHOME));
$HALOG = "$VCSHOME/bin/halog";
$VCSAG_OS = "UNIX";

$FILE_NAME = $0;

# set entry point
$VCS_LOG_SCRIPT_NAME = basename ($FILE_NAME);

# set agent name
$AGENT_DIR = dirname ($FILE_NAME);
$VCS_LOG_AGENT_NAME = basename ($AGENT_DIR);

# special treatment to action entry point
if ($VCS_LOG_AGENT_NAME eq $ACTION_ENTRY_PT)
{
    $VCS_LOG_SCRIPT_NAME = $VCS_LOG_AGENT_NAME;
    $AGENT_DIR = dirname (dirname ($FILE_NAME));
    $VCS_LOG_AGENT_NAME = basename ($AGENT_DIR);
}

# set category-id
($SYSTEM) = uname ();
if ($SYSTEM eq "AIX")
{
    $VCS_LOG_CATEGORY = 10011;
}
elsif ($SYSTEM eq "HP-UX")
{
    $VCS_LOG_CATEGORY = 10021;
}
elsif ($SYSTEM eq "Linux")
{
    $VCS_LOG_CATEGORY = 10031;
}
elsif ($SYSTEM eq "SunOS")
{
    $VCS_LOG_CATEGORY = 10001;
}
else # if ($SYSTEM eq "Windows NT")
{
    $VCS_LOG_CATEGORY = 10041;
    $HALOG = "\"$VCSHOME\\bin\\halog\"";
    $VCSAG_OS = "WINDOWS";
} 	

$ENV{VCS_LOG_AGENT_NAME} = $VCS_LOG_AGENT_NAME;
$ENV{VCS_LOG_SCRIPT_NAME} = $VCS_LOG_SCRIPT_NAME;
$ENV{VCS_LOG_CATEGORY} = $VCS_LOG_CATEGORY;


# set the environment variables required for logging.
# this function must be called once before calling the
# logging function VCSAG_LOG_MSG/VCSAG_LOGDBG_MSG
#
# usage:
# 0. VCSAG_SET_ENVS () # only for triggers
# 1. VCSAG_SET_ENVS ($resource_name)
# 2. VCSAG_SET_ENVS ($resource_name, $category)
# 3. VCSAG_SET_ENVS ($resource_name, $entry_point)
# 4. VCSAG_SET_ENVS ($resource_name, $category, $entry_point)
# 5. VCSAG_SET_ENVS ($resource_name, $entry_point, $category)
sub VCSAG_SET_ENVS
{
    # resource name and/or category and/or entry point.
    # passed by caller [optional]
    my ($VCS_LOG_RESOURCE_NAME, $OPT_ARG1, $OPT_ARG2) = @_;

    if ($#_ == -1) # for triggers
    {
        $ENV{VCS_LOG_CATEGORY} = 1;
        $ENV{VCS_LOG_AGENT_NAME} = "";
        return;
    }

    $ENV{VCS_LOG_RESOURCE_NAME} = $VCS_LOG_RESOURCE_NAME;

    if ($OPT_ARG1)
    {
        if ($OPT_ARG1 !~ /\D/)
        {
            $ENV{VCS_LOG_CATEGORY} = $OPT_ARG1;
        }
        elsif ($OPT_ARG1 !~ /[^a-z]/)
        {
            $ENV{VCS_LOG_SCRIPT_NAME} = $OPT_ARG1;
        }
    }

    if ($OPT_ARG2)
    {
        if ($OPT_ARG2 !~ /\D/)
        {
            $ENV{VCS_LOG_CATEGORY} = $OPT_ARG2;
        }
        elsif ($OPT_ARG2 !~ /[^a-z]/)
        {
            $ENV{VCS_LOG_SCRIPT_NAME} = $OPT_ARG2;
        }
    }
}


# all perl entry points must use this function if it is not a debug msg.
#
# usage:
# 1. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>)
# 2. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>, "$param1")
# 3. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>, "-encoding <encoding>")
# 4. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>, "-encoding <encoding>", "$param1")
#
# example:
# 1. VCSAG_LOG_MSG ("N", "a test message", 1);
# 2. VCSAG_LOG_MSG ("N", "a test message of $test", 1, "$test")
# 3. VCSAG_LOG_MSG ("N", "a test message", 1, "-encoding utf8")
# 4. VCSAG_LOG_MSG ("N", "a test message of $test", 1, "-encoding utf8", "$test")
sub VCSAG_LOG_MSG
{
    # @params includes "-encoding <encoding>" and all the parameters.
    # caller needs to make sure that it has passed the parameters in
    # the correct order.
    # if <encoding> is passed as an argument then the format of the
    # params would be :
    # $params[0] = "-encoding <encoding>"
    # $params[1] = <param1>
    # $params[2] = <param2> and so on.
    # otherwise :
    # $params[0] = <param1>
    # $params[1] = <param2> and so on.
    my ($severity, $msg, $msgid, @params) = @_;
    my ($encoding, $param_idx, $parameters, $i, $log_msg);

    $encoding = "";
    $param_idx = 0;

    $encoding = $params[0] if ($params[0] =~ /^\s*-encoding\s/);
    $param_idx = 1 if ($encoding);

    for ($i = $param_idx; $i <= $#params; $i++)
    {
        $params[$i] = "%$params[$i]" if ($params[$i] =~ /^-/);
        $parameters .= "\"$params[$i]\" ";
    }

    $parameters = "-parameters " . "$parameters" if ("$parameters");
    if ($severity eq "N") { $severity = "E"; }	
    if ($severity eq "E") { $severity = "B"; }	
    if ($severity eq "W") { $severity = "C"; }	

    $log_msg = "$HALOG -add $severity \"$msg\" -msgid $msgid";
    $log_msg .= " $encoding $parameters";

    if ($VCSAG_OS eq "UNIX")
    {
        system ($log_msg);
    }
    else # if ($VCSAG_OS eq "WINDOWS")
    {
        system ("\"$log_msg\"");
    }
}


1;
